## Version 0.1.4 (2021-05-12)
### 👷 Bug fixes

- setup.py

## Version 0.1.3 (2021-05-12)
### 👷 Bug fixes

- packaging: depend on cubicweb 3.27

## Version 0.1.2 (2021-05-11)

- packaging

## Version 0.1.1 (2021-05-11)
### 🤷 Various changes

- First working version
